@@ -8,6 +8,11 @@
 #ifndef parserutils_functypes_h_
 #define parserutils_functypes_h_
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 #include <stdbool.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -17,5 +22,9 @@
 /* Type of allocation function for parserutils */
 typedef void *(*parserutils_alloc)(void *ptr, size_t size, void *pw);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
